# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/getr',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/getr',
                'lib_path': 'getr'},
  'syms': { 'getr.attr': { 'getr.attr.getaffinity': ('attr.html#getaffinity', 'getr/attr.py'),
                           'getr.attr.getcat': ('attr.html#getcat', 'getr/attr.py'),
                           'getr.attr.getcategories': ('attr.html#getcategories', 'getr/attr.py'),
                           'getr.attr.getcentroids': ('attr.html#getcentroids', 'getr/attr.py'),
                           'getr.attr.getclusters': ('attr.html#getclusters', 'getr/attr.py'),
                           'getr.attr.getcodes': ('attr.html#getcodes', 'getr/attr.py'),
                           'getr.attr.getcols': ('attr.html#getcols', 'getr/attr.py'),
                           'getr.attr.getcolumns': ('attr.html#getcolumns', 'getr/attr.py'),
                           'getr.attr.getdata': ('attr.html#getdata', 'getr/attr.py'),
                           'getr.attr.getdf': ('attr.html#getdf', 'getr/attr.py'),
                           'getr.attr.getdfds': ('attr.html#getdfds', 'getr/attr.py'),
                           'getr.attr.getdiffop': ('attr.html#getdiffop', 'getr/attr.py'),
                           'getr.attr.getdiffpot': ('attr.html#getdiffpot', 'getr/attr.py'),
                           'getr.attr.getds': ('attr.html#getds', 'getr/attr.py'),
                           'getr.attr.getembedding': ('attr.html#getembedding', 'getr/attr.py'),
                           'getr.attr.getgraph': ('attr.html#getgraph', 'getr/attr.py'),
                           'getr.attr.geticat': ('attr.html#geticat', 'getr/attr.py'),
                           'getr.attr.getidx': ('attr.html#getidx', 'getr/attr.py'),
                           'getr.attr.getiloc': ('attr.html#getiloc', 'getr/attr.py'),
                           'getr.attr.getindex': ('attr.html#getindex', 'getr/attr.py'),
                           'getr.attr.getkdegree': ('attr.html#getkdegree', 'getr/attr.py'),
                           'getr.attr.getkernel': ('attr.html#getkernel', 'getr/attr.py'),
                           'getr.attr.getloc': ('attr.html#getloc', 'getr/attr.py'),
                           'getr.attr.getncol': ('attr.html#getncol', 'getr/attr.py'),
                           'getr.attr.getnrow': ('attr.html#getnrow', 'getr/attr.py'),
                           'getr.attr.getshape': ('attr.html#getshape', 'getr/attr.py'),
                           'getr.attr.iscatacc': ('attr.html#iscatacc', 'getr/attr.py')},
            'getr.atyp': {},
            'getr.cons': {},
            'getr.core': { 'getr.core._get': ('core.html#_get', 'getr/core.py'),
                           'getr.core.getr': ('core.html#getr', 'getr/core.py'),
                           'getr.core.make': ('core.html#make', 'getr/core.py'),
                           'getr.core.name': ('core.html#name', 'getr/core.py'),
                           'getr.core.onto': ('core.html#onto', 'getr/core.py'),
                           'getr.core.qual': ('core.html#qual', 'getr/core.py')},
            'getr.grds': { 'getr.grds.isdata': ('grds.html#isdata', 'getr/grds.py'),
                           'getr.grds.isgraph': ('grds.html#isgraph', 'getr/grds.py'),
                           'getr.grds.isshaped': ('grds.html#isshaped', 'getr/grds.py')}}}
