# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_cons.ipynb.

# %% auto 0
__all__ = ['DataTypes', 'ShapedTypes', 'GraphTypes', 'empty']

# %% ../nbs/00_cons.ipynb 4
from typing import TypeGuard, Union

# %% ../nbs/00_cons.ipynb 6
from itry import npmatrix, nparray, sparray, spmatrix, anndata
from itry import bgraph, dgraph, kgraph, tgraph, lgraph, mgraph, tlgraph, klgraph, mlgraph
from itry import pdindex, pdseries, pdcatindex, pddataframe
from itry import pttensor, ptinttensor, ptbooltensor, ptfloattensor
from itry import earray

# %% ../nbs/00_cons.ipynb 7
DataTypes = (npmatrix, nparray, sparray, spmatrix, anndata)
ShapedTypes = (*DataTypes, pdindex, pdseries, pdcatindex, pddataframe, pttensor, ptinttensor, ptbooltensor, ptfloattensor)
GraphTypes = (bgraph, dgraph, kgraph, tgraph, lgraph, mgraph, tlgraph, klgraph, mlgraph)

empty = earray
